"""pkmodel is a Pharmokinetic modelling library.

It contains functionality for creating, solving, and visualising the solution
of Parmokinetic (PK) models

"""
# # Import version info
# __version__ = importlib.metadata.version(__name__)

# # Import main classes
# from .model import Model    # noqa